Pootle
======

.. image:: https://api.travis-ci.org/translate/pootle.png
    :alt: Build Status
    :target: https://travis-ci.org/translate/pootle

.. image:: https://pypip.in/download/Pootle/badge.png
    :alt: Downloads
    :target: https://pypi.python.org/pypi/Pootle/

.. image:: https://pypip.in/py_versions/Pootle/badge.png
    :alt: Supported Python versions
    :target: https://pypi.python.org/pypi/Pootle/

.. image:: https://pypip.in/status/Pootle/badge.png
    :alt: Development Status
    :target: https://pypi.python.org/pypi/Pootle/

.. image:: https://pypip.in/license/Pootle/badge.svg
    :target: https://pypi.python.org/pypi/Pootle/
    :alt: License

`Pootle <http://pootle.translatehouse.org/>`_ is an online translation and
localization tool.  It works to lower the barrier of entry, providing tools to
enable teams to work towards higher quality while welcoming newcomers.


Warning
-------

**Pootle 2.6.x is not meant to be installed for new deployments. Pootle 2.6.x
is provided only to be used as an intermediate step for upgrading older Pootle
deployments to newer Pootle releases like 2.7.x or later.**

**Please install the latest stable release instead.**



Resources
---------

- `Pootle Website <http://pootle.translatehouse.org/>`_
- `Documentation <http://docs.translatehouse.org/projects/pootle/>`_
- `Translations <http://pootle.locamotion.org/projects/pootle/>`_
- `Bug Tracker <https://github.com/translate/pootle/issues>`_
- `Mailing List
  <https://lists.sourceforge.net/lists/listinfo/translate-pootle>`_
- IRC: `#pootle on irc.freenode.org <irc://irc.freenode.net/#pootle>`_

Copying
-------

Pootle is released under the General Public License, version 2 or later. See
the file LICENSE for details.
